<?
// Copyright 2002 Timothy Scott Morizot
//
// This file is part of my Easy Firewall Generator for IPTables.
//
// Easy Firewall Generator for IPTables is free software;
// you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// Easy Firewall Generator for IPTables is distributed
// in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// in this distribution; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

// Changelog:
//
// Version 1.07
//
// 10/16/2002 - tsm: Made transparent proxy comment out HTTPS option by
//                   default
//
// 10/16/2002 - tsm: Changed to use $_POST
//
// Version 1.06
//
// 06/27/2002 - tsm: Added rule options for the multicast
//                   packets seen from cable modems.
//                   Fixed the TTL rule.
//
// Version 1.05
//
// 05/22/2002 - tsm: Modified default behavior of bad_tcp_packets chain
//                   so packets originating from the internal interface
//                   (if one exists) are not processed through the
//                   chain.  Provided expanded comments and alternative
//                   rules.
//                   Ensured all lines in the resulting file are 80
//                   columns or less.
//
// 05/21/2002 - tsm: Fixed bug that added postrouting rule for single
//                   system as well as gateway.
//                   Drop INPUT broadcasts immediately before logging.
// Version 1.04
//
// 05/20/2002 - tsm: Fixed bug that failed to properly record static IP address.
//                   Added code to allow system to act a dhcp server.
//                   The autoconfig kludge is now more elegantly solved by
//                   an Internal DHCP setting that specifically allows
//                   DHCP packets from clients through the internal interface.
//                   Some of the explicit returns from chains were missing.
//                   Set internal output to internal interface to IP or IFACE.
//                   Corrected bug that printed literal value, not variable
//                   name.
//
// Version 1.03
//
// 05/20/2002 - tsm: Added sysctl option to change kernel parameters.
//                   Expanded the comments explaining the udp_inbound
//                   netbios rules.
//                   Added comments to allow script to work with Redhat's
//                   chkconfig implementation
//
//
// 05/17/2002 - tsm: Expand further on comments
//                   Fixed FTP Client inbound port rule
//                   Fixed OUTPUT chain rule for local_ip, only if there is one
//                   Explicitly drop inbound netbios (137,138)
//                   requests in udp_inbound without logging.  Cuts down
//                   on noise in the logs if in an area with lots of windows
//                   machines.  Only affects internet interface.
//                   Explicitly accept LO_IFACE on OUTPUT chain
//
// 05/16/2002 - tsm: Added detail to the kernel module and proc setting sections
//                   Added actions for arguments save and restore
//                   Added generic bad_packets chain - call it first everywhere
//                   except in OUTPUT chain. May add later.
//                   Added invalid ICMP packets to OUTPUT
//                   chain to remedy potential exploit.

//Set type to plain text
header("Content-Type: text/plain");

?>
#!/bin/sh
#
# Generated iptables firewall script for the Linux 2.4 kernel
# Script generated by Easy Firewall Generator for IPTables
# copyright 2002 Timothy Scott Morizot
# 
# Redhat chkconfig comments - firewall applied early,
#                             removed late
# chkconfig: 2345 08 92
# description: This script applies or removes iptables firewall rules
# 
# This generator is primarily designed for RedHat installations,
# although it should be adaptable for others.
#
# It can be executed with the typical start and stop arguments.
# If used with stop, it will stop after flushing the firewall.
# The save and restore arguments will save or restore the rules
# from the /etc/sysconfig/iptables file.

# Redhat installation instructions
#
# 1. Ensure that ipchains will not automatically start.
#    chkconfig --level 0123456 ipchains off
#    This will make sure that the ipchains init.d script
#    is not linked to an S file in any of the rc directories.
#
# 2. Stop ipchains if it's running.
#    service ipchains stop
#
# 3. Execute lsmod to see if the ipchains kernel module is still loaded.
#    If it is, use rmmod to unload it. -- rmmod ipchains
#
# 4. Have the system link the iptables init.d startup script into run states
#    2, 3, and 5.
#    chkconfig --level 235 iptables on
#
# 5. Save this script and execute it to load the ruleset from this file.
#    You may need to run the dos2unix command on it to remove carraige returns.
#
# 6. Save the ruleset to /etc/sysconfig/iptables.  This can be done two ways.
#    service iptables save
#    iptables-save > /etc/sysconfig/iptables
#
# 7. The ruleset will be restored by the /etc/init.d/iptables script on boot.
# 
# 8. Alternatively, save the /etc/init.d/iptables script and copy this script
#    to /etc/init.d/iptables.  It accepts stop, start, save, and restore
#    arguments.
#
# NOTE: The /etc/init.d/iptables script can be modified to run this script
# instead.  If you do so, save a copy so you can reapply your modifications
# after upgrading the iptables package.  The advantage of using this script for
# the ongoing operation of the firewall is it gives you greater control over
# the modules and rulesets used.  The above is simpler, however.

###############################################################################
# 
# Local Settings
#

# sysctl location.  If set, it will use sysctl to adjust the kernel parameters.
# If this is set to the empty string (or is unset), the use of sysctl
# is disabled.

SYSCTL="/sbin/sysctl -w" 

# To echo the value directly to the /proc file instead
# SYSCTL=""

# IPTables Location - adjust if needed

IPT="/sbin/iptables"
IPTS="/sbin/iptables-save"
IPTR="/sbin/iptables-restore"

# Internet Interface
<?
print("INET_IFACE=\"" . $_POST['INET_IFACE'] . "\"\n");

if ($_POST['DYNAMIC_IP'] != "true")
{
	print("INET_ADDRESS=\"" . $_POST['INET_ADDRESS'] . "\"\n");
}	

if ($_POST['GATEWAY'] == "true")
{
	print("\n# Local Interface Information\n");
	print("LOCAL_IFACE=\"" . $_POST['LOCAL_IFACE'] . "\"\n");
	print("LOCAL_IP=\"" . $_POST['LOCAL_IP'] . "\"\n");
	print("LOCAL_NET=\"" . $_POST['LOCAL_NET'] . "\"\n");
	print("LOCAL_BCAST=\"" . $_POST['LOCAL_BCAST'] . "\"\n");
}

?>

# Localhost Interface

LO_IFACE="lo"
LO_IP="127.0.0.1"

# Save and Restore arguments handled here
if [ "$1" = "save" ]
then
	echo -n "Saving firewall to /etc/sysconfig/iptables ... "
	$IPTS > /etc/sysconfig/iptables
	echo "done"
	exit 0
elif [ "$1" = "restore" ]
then
	echo -n "Restoring firewall from /etc/sysconfig/iptables ... "
	$IPTR < /etc/sysconfig/iptables
	echo "done"
	exit 0
fi

###############################################################################
#
# Load Modules
#

echo "Loading kernel modules ..."

# You should uncomment the line below and run it the first time just to
# ensure all kernel module dependencies are OK.  There is no need to run
# every time, however.

# /sbin/depmod -a

# Unless you have kernel module auto-loading disabled, you should not
# need to manually load each of these modules.  Other than ip_tables,
# ip_conntrack, and some of the optional modules, I've left these
# commented by default.  Uncomment if you have any problems or if
# you have disabled module autoload.  Note that some modules must
# be loaded by another kernel module.

# core netfilter module
/sbin/modprobe ip_tables

# the stateful connection tracking module
/sbin/modprobe ip_conntrack

# filter table module
# /sbin/modprobe iptable_filter

# mangle table module
# /sbin/modprobe iptable_mangle

# nat table module
# /sbin/modprobe iptable_nat

# LOG target module
# /sbin/modprobe ipt_LOG

# This is used to limit the number of packets per sec/min/hr
# /sbin/modprobe ipt_limit

# masquerade target module
# /sbin/modprobe ipt_MASQUERADE

# filter using owner as part of the match
# /sbin/modprobe ipt_owner

# REJECT target drops the packet and returns an ICMP response.
# The response is configurable.  By default, connection refused.
# /sbin/modprobe ipt_REJECT

# This target allows packets to be marked in the mangle table
# /sbin/modprobe ipt_mark

# This target affects the TCP MSS
# /sbin/modprobe ipt_tcpmss

# This match allows multiple ports instead of a single port or range
# /sbin/modprobe multiport

# This match checks against the TCP flags
# /sbin/modprobe ipt_state

# This match catches packets with invalid flags
# /sbin/modprobe ipt_unclean

<?

print("# The ftp nat module is required for non-PASV ftp support\n");
if ($_POST['FTP_OUT'] == "true")
{
	print("#");
}
print("/sbin/modprobe ip_nat_ftp\n\n");

print("# the module for full ftp connection tracking\n");
if ($_POST['FTP_OUT'] == "true")
{
	print("#");
}
print("/sbin/modprobe ip_conntrack_ftp\n\n");

print("# the module for full irc connection tracking\n");
if ($_POST['IRC_OUT'] == "true")
{
	print("#");
}
print("/sbin/modprobe ip_conntrack_irc\n\n");

?>

###############################################################################
#
# Kernel Parameter Configuration
#

<?
print("# Required to enable IPv4 forwarding.\n");
print("# Redhat users can try setting FORWARD_IPV4 in /etc/sysconfig/network to true\n");
if ($_POST['GATEWAY'] == "false")
{
	print("#if [ \"\$SYSCTL\" = \"\" ]\n");
	print("#then\n");
	print("#    echo \"1\" > /proc/sys/net/ipv4/ip_forward\n");
	print("#else\n");
	print("#    \$SYSCTL net.ipv4.ip_forward=\"1\"\n");
	print("#fi\n\n");
}
else
{
	print("if [ \"\$SYSCTL\" = \"\" ]\n");
	print("then\n");
	print("    echo \"1\" > /proc/sys/net/ipv4/ip_forward\n");
	print("else\n");
	print("    \$SYSCTL net.ipv4.ip_forward=\"1\"\n");
	print("fi\n\n");
}

print("# This enables dynamic address hacking.\n");
print("# Set this if you have a dynamic IP address \(e.g. slip, ppp, dhcp\).\n");
if ($_POST['DYNAMIC_IP'] == "false")
{
	print("#if [ \"\$SYSCTL\" = \"\" ]\n");
	print("#then\n");
	print("#    echo \"1\" > /proc/sys/net/ipv4/ip_dynaddr\n");
	print("#else\n");
	print("#    \$SYSCTL net.ipv4.ip_dynaddr=\"1\"\n");
	print("#fi\n\n");
}
else
{
	print("if [ \"\$SYSCTL\" = \"\" ]\n");
	print("then\n");
	print("    echo \"1\" > /proc/sys/net/ipv4/ip_dynaddr\n");
	print("else\n");
	print("    \$SYSCTL net.ipv4.ip_dynaddr=\"1\"\n");
	print("fi\n\n");
}

print("# This enables source validation by reversed path according to RFC1812.\n");
print("# In other words, did the response packet originate from the same interface\n");
print("# through which the source packet was sent?  It's recommended for single-homed\n");
print("# systems and routers on stub networks.  Since those are the configurations\n");
print("# this firewall is designed to support, I turn it on by default.\n");
print("# Turn it off if you use multiple NICs connected to the same network.\n");
print("if [ \"\$SYSCTL\" = \"\" ]\n");
print("then\n");
print("    echo \"1\" > /proc/sys/net/ipv4/conf/all/rp_filter\n");
print("else\n");
print("    \$SYSCTL net.ipv4.conf.all.rp_filter=\"1\"\n");
print("fi\n\n");

print("# This option allows a subnet to be firewalled with a single IP address.\n");
print("# It's used to build a DMZ.  Since that's not a focus of this firewall\n");
print("# script, it's not enabled by default, but is included for reference.\n");
print("# See: http://www.sjdjweis.com/linux/proxyarp/ \n");
print("#if [ \"\$SYSCTL\" = \"\" ]\n");
print("#then\n");
print("#    echo \"1\" > /proc/sys/net/ipv4/conf/all/proxy_arp\n");
print("#else\n");
print("#    \$SYSCTL net.ipv4.conf.all.proxy_arp=\"1\"\n");
print("#fi\n\n");

?>

###############################################################################
#
# Flush Any Existing Rules or Chains
#

echo "Flushing Tables ..."

# Reset Default Policies
$IPT -P INPUT ACCEPT
$IPT -P FORWARD ACCEPT
$IPT -P OUTPUT ACCEPT
$IPT -t nat -P PREROUTING ACCEPT
$IPT -t nat -P POSTROUTING ACCEPT
$IPT -t nat -P OUTPUT ACCEPT
$IPT -t mangle -P PREROUTING ACCEPT
$IPT -t mangle -P OUTPUT ACCEPT

# Flush all rules
$IPT -F
$IPT -t nat -F
$IPT -t mangle -F

# Erase all non-default chains
$IPT -X
$IPT -t nat -X
$IPT -t mangle -X

if [ "$1" = "stop" ]
then
	echo "Firewall completely flushed!  Now running with no firewall."
	exit 0
fi

###############################################################################
#
# Rules Configuration
#

###############################################################################
#
# Filter Table
#
###############################################################################

# Set Policies

$IPT -P INPUT DROP
$IPT -P OUTPUT DROP
$IPT -P FORWARD DROP

###############################################################################
#
# User-Specified Chains
#
# Create user chains to reduce the number of rules each packet
# must traverse.

echo "Create and populate custom rule chains ..."

# Create a chain to filter INVALID packets

$IPT -N bad_packets

# Create another chain to filter bad tcp packets

$IPT -N bad_tcp_packets

# Create separate chains for icmp, tcp (incoming and outgoing),
# and incoming udp packets.

$IPT -N icmp_packets

# Used for UDP packets inbound from the Internet
$IPT -N udp_inbound

# Used to block outbound UDP services from internal network
# Default to allow all
$IPT -N udp_outbound

# Used to allow inbound services if desired
# Default fail except for established sessions
$IPT -N tcp_inbound

# Used to block outbound services from internal network
# Default to allow all
$IPT -N tcp_outbound

###############################################################################
#
# Populate User Chains
#

# bad_packets chain
#
# Drop INVALID packets immediately

$IPT -A bad_packets -p ALL -m state --state INVALID -j LOG \
    --log-prefix "Invalid packet:"
$IPT -A bad_packets -p ALL -m state --state INVALID -j DROP

# Then check the tcp packets for additional problems
$IPT -A bad_packets -p tcp -j bad_tcp_packets

# All good, so return
$IPT -A bad_packets -p ALL -j RETURN

# bad_tcp_packets chain
#
# All tcp packets will traverse this chain.
# Every new connection attempt should begin with
# a syn packet.  If it doesn't, it is likely a
# port scan.  This drops packets in state
# NEW that are not flagged as syn packets.

<?
//If there is a gateway, exempt the internal interface.
if ($_POST['GATEWAY'] == "true")
{
	print("# Return to the calling chain if the bad packets originate\n");
	print("# from the local interface. This maintains the approach\n");
	print("# throughout this firewall of a largely trusted internal\n");
	print("# network.\n");
	print("\$IPT -A bad_tcp_packets -p tcp -i \$LOCAL_IFACE -j RETURN\n\n");

	print("# However, I originally did apply this filter to the forward chain\n");
	print("# for packets originating from the internal network.  While I have\n");
	print("# not conclusively determined its effect, it appears to have the\n");
	print("# interesting side effect of blocking some of the ad systems.\n");
	print("# Apparently some ad systems have the browser initiate a NEW\n");
	print("# connection that is not flagged as a syn packet to retrieve\n");
	print("# the ad image.  If you wish to experiment further comment the\n");
	print("# rule above. If you try it, you may also wish to uncomment the\n");
	print("# rule below.  It will keep those packets from being logged.\n");
	print("# There are a lot of them.\n");
	print("# \$IPT -A bad_tcp_packets -p tcp -i \$LOCAL_IFACE ! --syn -m state \\\n");
	print("#     --state NEW -j DROP\n");
}
?>

$IPT -A bad_tcp_packets -p tcp ! --syn -m state --state NEW -j LOG \
    --log-prefix "New not syn:"
$IPT -A bad_tcp_packets -p tcp ! --syn -m state --state NEW -j DROP

# All good, so return
$IPT -A bad_tcp_packets -p tcp -j RETURN

# icmp_packets chain
#
# This chain is for inbound (from the Internet) icmp packets only.
# Type 8 (Echo Request) is not accepted by default
# Enable it if you want remote hosts to be able to reach you.
# 11 (Time Exceeded) is the only one accepted
# that would not already be covered by the established
# connection rule.  Applied to INPUT on the external interface.
# 
# See: http://www.ee.siue.edu/~rwalden/networking/icmp.html
# for more info on ICMP types.
#
# Note that the stateful settings allow replies to ICMP packets.
# These rules allow new packets of the specified types.

# Echo - uncomment to allow your system to be pinged.
# $IPT -A icmp_packets -p ICMP -s 0/0 --icmp-type 8 -j ACCEPT

# Time Exceeded
$IPT -A icmp_packets -p ICMP -s 0/0 --icmp-type 11 -j ACCEPT

# Not matched, so return so it will be logged
$IPT -A icmp_packets -p ICMP -j RETURN

# TCP & UDP
# Identify ports at:
#    http://www.chebucto.ns.ca/~rakerman/port-table.html
#    http://www.iana.org/assignments/port-numbers

# udp_inbound chain
#
# This chain describes the inbound UDP packets it will accept.
# It's applied to INPUT on the external or Internet interface.
# Note that the stateful settings allow replies.
# These rules are for new requests.
# It drops netbios packets (windows) immediately without logging.

# Drop netbios calls
# Please note that these rules do not really change the way the firewall
# treats netbios connections.  Connections from the localhost and
# internal interface (if one exists) are accepted by default.
# Responses from the Internet to requests initiated by or through
# the firewall are also accepted by default.  To get here, the
# packets would have to be part of a new request received by the
# Internet interface.  You would have to manually add rules to
# accept these.  I added these rules because some network connections,
# such as those via cable modems, tend to be filled with noise from
# unprotected Windows machines.  These rules drop those packets
# quickly and without logging them.  This prevents them from traversing
# the whole chain and keeps the log from getting cluttered with
# chatter from Windows systems.
$IPT -A udp_inbound -p UDP -s 0/0 --destination-port 137 -j DROP
$IPT -A udp_inbound -p UDP -s 0/0 --destination-port 138 -j DROP

<?
//NTP server on gateway
if ($_POST['NTP_IN'] == "true")
{
	print("# Network Time Protocol (NTP) Server\n");
	print("\$IPT -A udp_inbound -p UDP -s 0/0 --destination-port 123 -j ACCEPT\n\n");
}

//DNS Server on gateway
if ($_POST['DNS_IN'] == "true")
{
	print("# DNS Server\n");
	print("# Configure the server to use port 53 as the source port for requests\n");
	print("# Note, if you run a caching-only name server that only accepts queries\n");
	print("# from the private network or localhost, you can comment out this line.\n");
	print("\$IPT -A udp_inbound -p UDP -s 0/0 --destination-port 53 -j ACCEPT\n\n");
	print("# If you don't query-source the server to port 53 and you have problems,\n");
	print("# uncomment this rule.  It specifically allows responses to queries\n");
	print("# initiated to another server from a high UDP port.  The stateful\n");
	print("# connection rules should handle this situation, though.\n");
	print("# \$IPT -A udp_inbound -p UDP -s 0/0 --source-port 53 -j ACCEPT\n\n");
}

// If running a DHCP server on the Internet interface, allow the requests
if ($_POST['DHCP_IN'] == "true")
{
	print("# External DHCP Server\n");
	print("# Allow DHCP client request packets inbound from external network\n");
	print("\$IPT -A udp_inbound -p UDP -s 0/0 --source-port 68 --destination-port 67 \\\n");
	print("     -j ACCEPT\n\n");
}

//If it's a dynamic address, set rule to allow inbound DHCP
if ($_POST['DYNAMIC_IP'] == "true")
{
	print("# Dynamic Address\n");
	print("# If DHCP, the initial request is a broadcast. The response\n");
	print("# doesn't exactly match the outbound packet.  This explicitly\n");
	print("# allow the DHCP ports to alleviate this problem.\n");
	print("# If you receive your dynamic address by a different means, you\n");
	print("# can probably comment this line.\n");
	print("\$IPT -A udp_inbound -p UDP -s 0/0 --source-port 67 --destination-port 68 \\\n");
	print("     -j ACCEPT\n\n");
}

?>

# Not matched, so return for logging
$IPT -A udp_inbound -p UDP -j RETURN

# udp_outbound chain
#
# This chain is used with a private network to prevent forwarding for
# UDP requests on specific protocols.  Applied to the FORWARD rule from
# the internal network.  Ends with an ACCEPT

<?

//If IM blocked, block ICQ, which uses UDP 4000
if ($_POST['IM_OUT'] == "true")
{
	print("# ICQ uses UDP 4000 - Instant messaging blocked\n");
	print("\$IPT -A udp_outbound -p UDP -s 0/0 --destination-port 4000 -j REJECT\n\n");
}

?>

# No match, so ACCEPT
$IPT -A udp_outbound -p UDP -s 0/0 -j ACCEPT

# tcp_inbound chain
#
# This chain is used to allow inbound connections to the
# system/gateway.  Use with care.  It defaults to none.
# It's applied on INPUT from the external or Internet interface.

# DOCSIS compliant cable modems
# Some DOCSIS compliant cable modems send IGMP multicasts to find
# connected PCs.  The multicast packets have the destination address
# 224.0.0.1.  You can accept them.  If you choose to do so,
# Uncomment the rule to ACCEPT them and comment the rule to DROP
# them  The firewall will drop them here by default to avoid
# cluttering the log
# Drop them without logging.
$IPT -A tcp_inbound -p TCP -d 224.0.0.1 -j DROP
# The rule to accept the packets.
# $IPT -A tcp_inbound -p TCP -d 224.0.0.1 -j ACCEPT

<?

//DNS Server - TCP (most are UDP, so this could be disabled)
if ($_POST['DNS_IN'] == "true")
{
	print("# DNS Server - Allow TCP connections (zone transfers and large requests)\n");
	print("# This is disabled by default.  DNS Zone transfers occur via TCP.\n");
	print("# If you need to allow transfers over the net you need to uncomment this line.\n");
	print("# If you allow queries from the 'net, you also need to be aware that although\n");
	print("# DNS queries use UDP by default, a truncated UDP query can legally be\n");
	print("# submitted via TCP instead.  You probably will never need it, but should\n");
	print("# be aware of the fact.\n");
	print("# \$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 53 -j ACCEPT\n\n");
}

//HTTP
if ($_POST['HTTP_IN'] == "true")
{
	print("# Web Server\n\n");
	print("# HTTP\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 80 -j ACCEPT\n\n");
	print("# HTTPS (Secure Web Server)\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 443 -j ACCEPT\n\n");
}

//FTP
if ($_POST['FTP_IN'] == "true")
{
	print("# FTP Server (Control)\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 21 -j ACCEPT\n\n");
	print("# FTP Client (Data Port for non-PASV transfers)\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --source-port 20 -j ACCEPT\n\n");
}

//Email
if ($_POST['EMAIL_IN'] == "true")
{
	print("# Email Server (SMTP)\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 25 -j ACCEPT\n\n");
	print("# Email Server (POP3)\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 110 -j ACCEPT\n\n");
	print("# Email Server (IMAP4)\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 143 -j ACCEPT\n\n");
}

//SSH
if ($_POST['SSH_IN'] == "true")
{
	print("# sshd\n");
	print("\$IPT -A tcp_inbound -p TCP -s 0/0 --destination-port 22 -j ACCEPT\n\n");
}

?>

# Not matched, so return so it will be logged
$IPT -A tcp_inbound -p TCP -j RETURN

# tcp_outbound chain
#
# This chain is used with a private network to prevent forwarding for
# requests on specific protocols.  Applied to the FORWARD rule from
# the internal network.  Ends with an ACCEPT

<?
if ($_POST['IRC_OUT'] == "true")
{
	print("# Block IRC\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 194 -j REJECT\n\n");
}

if ($_POST['TELNET_OUT'] == "true")
{
	print("# Block Outbound Telnet\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 23 -j REJECT\n\n");
}

if ($_POST['SSH_OUT'] == "true")
{
	print("# Block SSH\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 22 -j REJECT\n\n");
}

if ($_POST['NEWS_OUT'] == "true")
{
	print("# Block Usenet Access\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 119 -j REJECT\n\n");
}

if ($_POST['HTTP_OUT'] == "true")
{
	print("# Block Web Access\n\n");
	print("# HTTP\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 80 -j REJECT\n\n");
	print("# HTTPS (Secure Web)\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 443 -j REJECT\n\n");
}

if ($_POST['FTP_OUT'] == "true")
{
	print("# Block FTP Access\n\n");
	print("# Control\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 21 -j REJECT\n\n");
	print("# Data\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 20 -j REJECT\n\n");
}

if ($_POST['IM_OUT'] == "true")
{
	print("# Block Instant Messaging\n\n");
	print("# AIM\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 5190 -j REJECT\n\n");
	print("# AIM Images\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 4443 -j REJECT\n\n");
	print("# MSN Messenger\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 1863 -j REJECT\n\n");
}

if ($_POST['EMAIL_OUT'] == "true")
{
	print("# Block Email Access to external servers\n\n");
	print("# SMTP\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 25 -j REJECT\n\n");
	print("# POP3\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 110 -j REJECT\n\n");
	print("# IMAP4\n");
	print("\$IPT -A tcp_outbound -p TCP -s 0/0 --destination-port 143 -j REJECT\n\n");
}
?>

# No match, so ACCEPT
$IPT -A tcp_outbound -p TCP -s 0/0 -j ACCEPT

###############################################################################
#
# INPUT Chain
#

echo "Process INPUT chain ..."

# Allow all on localhost interface
$IPT -A INPUT -p ALL -i $LO_IFACE -j ACCEPT

# Drop bad packets
$IPT -A INPUT -p ALL -j bad_packets

<?
//Rules for the private network
if ($_POST['GATEWAY'] == "true")
{
	print("# Rules for the private network (accessing gateway system itself)\n");
	print("\$IPT -A INPUT -p ALL -i \$LOCAL_IFACE -s \$LOCAL_NET -j ACCEPT\n");
	print("\$IPT -A INPUT -p ALL -i \$LOCAL_IFACE -d \$LOCAL_BCAST -j ACCEPT\n\n");

// The following rule is the generic fix for these.
//	print("# Allow broadcasts from ipv4 autoconfig.  Windows XP uses this.\n");
//	print("# Others may as well.  Either of the following may be required.\n");
//	print("\$IPT -A INPUT -p ALL -i \$LOCAL_IFACE -d 169.254.255.255 -j ACCEPT\n");
//	print("\$IPT -A INPUT -p ALL -i \$LOCAL_IFACE -d 255.255.255.255 -j ACCEPT\n");

	//If running DHCP internally from this server, also allow dhcp client requests
	if ($_POST['INTERNAL_DHCP'] == "true")
	{
		print("# Allow DHCP client request packets inbound from internal network\n");
		print("\$IPT -A INPUT -p UDP -i \$LOCAL_IFACE --source-port 68 --destination-port 67 \\\n");
		print("     -j ACCEPT\n\n");
	}

}
?>

# Inbound Internet Packet Rules

# Accept Established Connections
$IPT -A INPUT -p ALL -i $INET_IFACE -m state --state ESTABLISHED,RELATED \
     -j ACCEPT

# Route the rest to the appropriate user chain
$IPT -A INPUT -p TCP -i $INET_IFACE -j tcp_inbound
$IPT -A INPUT -p UDP -i $INET_IFACE -j udp_inbound
$IPT -A INPUT -p ICMP -i $INET_IFACE -j icmp_packets

# Drop without logging broadcasts that get this far.
# Cuts down on log clutter.
# Comment this line if testing new rules that impact
# broadcast protocols.
$IPT -A INPUT -p ALL -d 255.255.255.255 -j DROP

# Log packets that still don't match
$IPT -A INPUT -m limit --limit 3/minute --limit-burst 3 -j LOG \
     --log-prefix "INPUT packet died: "

###############################################################################
#
# FORWARD Chain
#

echo "Process FORWARD chain ..."

# Used if forwarding for a private network

<?
// If private network exists
if ($_POST['GATEWAY'] == "true")
{
	print("# Drop bad packets");
	print("\$IPT -A FORWARD -p ALL -j bad_packets\n\n");

	print("# Accept TCP packets we want to forward from internal sources\n");
	print("\$IPT -A FORWARD -p tcp -i \$LOCAL_IFACE -j tcp_outbound\n\n");

	print("# Accept UDP packets we want to forward from internal sources\n");
	print("\$IPT -A FORWARD -p udp -i \$LOCAL_IFACE -j udp_outbound\n\n");

	print("# If not blocked, accept any other packets from the internal interface\n");
	print("\$IPT -A FORWARD -p ALL -i \$LOCAL_IFACE -j ACCEPT\n\n");

	print("# Deal with responses from the internet\n");
	print("\$IPT -A FORWARD -i \$INET_IFACE -m state --state ESTABLISHED,RELATED \\\n");
	print("     -j ACCEPT\n\n");

	print("# Log packets that still don't match\n");
	print("\$IPT -A FORWARD -m limit --limit 3/minute --limit-burst 3 -j LOG \\\n");
	print("     --log-prefix \"FORWARD packet died: \"\n\n");
}
?>

###############################################################################
#
# OUTPUT Chain
#

echo "Process OUTPUT chain ..."

# Generally trust the firewall on output

# However, invalid icmp packets need to be dropped
# to prevent a possible exploit.
$IPT -A OUTPUT -m state -p icmp --state INVALID -j DROP

# Localhost
$IPT -A OUTPUT -p ALL -s $LO_IP -j ACCEPT
$IPT -A OUTPUT -p ALL -o $LO_IFACE -j ACCEPT

<?
// If private network exists
if ($_POST['GATEWAY'] == "true")
{
	print("# To internal network\n");
	print("\$IPT -A OUTPUT -p ALL -s \$LOCAL_IP -j ACCEPT\n");
	print("\$IPT -A OUTPUT -p ALL -o \$LOCAL_IFACE -j ACCEPT\n\n");
}
?>
# To internet
$IPT -A OUTPUT -p ALL -o $INET_IFACE -j ACCEPT

# Log packets that still don't match
$IPT -A OUTPUT -m limit --limit 3/minute --limit-burst 3 -j LOG \
     --log-prefix "OUTPUT packet died: "

###############################################################################
#
# nat table
#
###############################################################################

# The nat table is where network address translation occurs if there
# is a private network.  If the gateway is connected to the Internet
# with a static IP, snat is used.  If the gateway has a dynamic address,
# masquerade must be used instead.  There is more overhead associated
# with masquerade, so snat is better when it can be used.
# The nat table has a builtin chain, PREROUTING, for dnat and redirects.
# Another, POSTROUTING, handles snat and masquerade.

echo "Load rules for nat table ..."

###############################################################################
#
# PREROUTING chain
#

<?
// If TRANSPARENT_PROXY option set, redirect port 80 and port 443 to the
// REDIRECT_PORT on the gateway machine
if ($_POST['TRANSPARENT_PROXY'] == "true")
{
	print("# This is a sample that will exempt a specific host from the transparent proxy\n");
	print("#\$IPT -t nat -A PREROUTING -p tcp -s 192.168.1.50 --destination-port 80 \\\n");
	print("#     -j RETURN\n");
	print("#\$IPT -t nat -A PREROUTING -p tcp -s 192.168.1.50 --destination-port 443 \\\n");
	print("#     -j RETURN\n\n");

	print("# Redirect HTTP for a transparent proxy\n");
	print("\$IPT -t nat -A PREROUTING -p tcp --destination-port 80 \\\n");
	print("     -j REDIRECT --to-ports " . $_POST['REDIRECT_PORT'] . "\n");
	print("# Redirect HTTPS for a transparent proxy - commented by default\n");
	print("# \$IPT -t nat -A PREROUTING -p tcp --destination-port 443 \\\n");
	print("#     -j REDIRECT --to-ports " . $_POST['REDIRECT_PORT'] . "\n");
}
?>

###############################################################################
#
# POSTROUTING chain
#

<?
//If it's a gateway then install either snat or masquerade.
if ($_POST['GATEWAY'] == "true")
{
	if ($_POST['DYNAMIC_IP'] == "true")	//use masquerade target
	{
		print("\$IPT -t nat -A POSTROUTING -o \$INET_IFACE -j MASQUERADE\n");
	}
	else						//static, so use snat target
	{
		print("\$IPT -t nat -A POSTROUTING -o \$INET_IFACE \\\n");
		print("     -j SNAT --to-source \$INET_ADDRESS\n");
	}
}
?>

###############################################################################
#
# mangle table
#
###############################################################################

# The mangle table is used to alter packets.  It can alter or mangle them in
# several ways.  For the purposes of this generator, we only use its ability
# to alter the TTL in packets.  However, it can be used to set netfilter
# mark values on specific packets.  Those marks could then be used in another
# table like filter, to limit activities associated with a specific host, for
# instance.  The TOS target can be used to set the Type of Service field in
# the IP header.  Note that the TTL target might not be included in the
# distribution on your system.  If it is not and you require it, you will
# have to add it.  That may require that you build from source.

echo "Load rules for mangle table ..."

<?
//Reset the TTL is requested to do so.
if ($_POST['MANGLE_TTL'] == "true")
{
	print("# Set the TTL in outbound packets to the same consistent value.\n");
	print("# A value around 128 is a good value.  Do not set this too high as\n");
	print("# it will adversely affect your network.  It is also considered bad\n");
	print("# form on the Internet.\n"); 
	print("\$IPT -t mangle -A OUTPUT -o \$INET_IFACE -j TTL --ttl-set ");
	print($_POST['TTL'] . "\n");
}
?>
